Learn R Programming

scaRabee (version 1.1-5)

convert.infusion: Process Infusion Information

Description

convert.infusion is a secondary function, which main purpose is to transform infusion information provided using NONMEM standards into an object that can be used by scaRabee model functions. convert.infusion is typically not called directly by users.

Usage

convert.infusion(infusion.data = NULL)

Value

Return a data.frame with the following variables: trt, time, state, bolus, and infusion.

Arguments

infusion.data

A data.frame with the following variables: trt, time, cmt, amt, and rate.

Author

Sebastien Bihorel (sb.pmlab@gmail.com)

See Also

scarabee.read.data