finalize.grid.report is a secondary function called at the end of the
direct grid search step of the direct grid search runs (this step is actually
by a simulation step). It outputs to the report file the grid search summary
table produced by scarabee.gridsearch. finalize.grid.report is
typically not called directly by users.
finalize.grid.report(problem = NULL,
fgrid = NULL,
files = NULL)Does not return any value.
A list containing the following levels:
A list which content depends on the scope of the analysis. If
the analysis was run at the level of the subject, data contains as
many levels as the number of subjects in the dataset, plus the ids
level containing the vector of identification numbers of all subjects
included in the analysis population. If the analysis was run at the level
of the population, data contains only one level of data and
ids is set to 1.
Each subject-specific level contains as many levels as there are treatment
levels for this subject, plus the trts level listing all treatments
for this subject, and the id level giving the identification number
of the subject.
Each treatment-specific levels is a list containing the following levels:
mij x 3 data.frame containing the times of observations of the dependent variables (extracted from the TIME variable), the indicators of the type of dependent variables (extracted from the CMT variable), and the actual dependent variable observations (extracted from the DV variable) for this particular treatment and this particular subject.
mij x c data.frame containing the times of observations of the dependent variables (extracted from the TIME variable) and all the covariates identified for this particular treatment and this particular subject.
bij x 4 data.frame providing the instantaneous inputs for a treatment and individual.
fij x (4+c) data.frame providing the zero-order inputs for a treatment and individual.
the particular treatment identifier.
A character string, indicating the scale of the analysis. Should be 'population' or 'subject'.
A data.frame of parameter data with the following columns: 'names', 'type', 'value', 'isfix', 'lb', and 'ub'.
Logical indicator of debugging mode.
Model function.
A data.frame with pe+2 columns. The last 2 columns report the value and the feasibility of the objective function at each specific vector of parameter estimates which is documented in the first pe columns. This data.frame must be ordered by feasibility and increasing value of the objective function.
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A .csv file reporting the values of the objective function and estimates of model parameters at each iteration. (Not used for direct grid search runs).
A text file reporting the summary tables of ordered objective function values for the various tested vectors of model parameters.
A .csv file reporting the predictions and calculated residuals for each individual in the dataset. (Not used for direct grid search runs).
A .csv file reporting the final parameter estimates for each individual in the dataset. (Not used for direct grid search runs).
A .csv file reporting the simulated model predictions for each individual in the dataset. (Not used for direct grid search runs).
Sebastien Bihorel (sb.pmlab@gmail.com)
scarabee.gridsearch,