fitmle is a secondary function called during estimation runs. It
performs the optimization of the model parameters by the method of the maximum
likelihood, i.e. the minimization of an objective function defined as the
exact negative log likelihood of the observed data, given the structural
model, the model of residual variability, and the parameter estimates. This
minimization is performed by the Nelder-Mead simplex algorithm implemented in
fminsearch from the neldermead package. fitmle is
typically not called directly by users.
fitmle(problem = NULL,
estim.options = NULL,
files = NULL)Return a list with two elements: estimations which contains the vector
of final parameter estimates and fval the minimal value of the
objective function.
A list containing the following levels:
A list containing as many levels as there are treatment levels
for the subject (or population) being evaluated, plus the trts
level listing all treatments for this subject (or population), and the
id level giving the identification number of the subject (or set to
1 if the analysis was run at the level of the population.
Each treatment-specific level is a list containing the following levels:
mij x 3 data.frame containing the times of observations of the dependent variables (extracted from the TIME variable), the indicators of the type of dependent variables (extracted from the CMT variable), and the actual dependent variable observations (extracted from the DV variable) for this particular treatment.
mij x c data.frame containing the times of observations of the dependent variables (extracted from the TIME variable) and all the covariates identified for this particular treatment.
bij x 4 data.frame providing the instantaneous inputs for a treatment and individual.
fij x (4+c) data.frame providing the zero-order inputs for a treatment and individual.
the particular treatment identifier.
A character string, indicating the scale of the analysis. Should be 'population' or 'subject'.
A data.frame of parameter data with the following columns: 'names', 'type', 'value', 'isfix', 'lb', and 'ub'.
Logical indicator of debugging mode.
Model function.
A list of estimation options containing two elements
maxiter (the maximum number of iterations) and maxeval (the
maximum number of function evaluations).
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A .csv file reporting the values of the objective function and estimates of model parameters at each iteration.
A text file reporting for each individual in the dataset the final parameter estimates for structural model parameters, residual variability and secondary parameters as well as the related statistics (coefficients of variation, confidence intervals, covariance and correlation matrix).
A .csv file reporting the predictions and calculated residuals for each individual in the dataset.
A .csv file reporting the final parameter estimates for each individual in the dataset.
A .csv file reporting the simulated model predictions for each individual in the dataset. (Not used for estimation runs).
Sebastien Bihorel (sb.pmlab@gmail.com)
Pawel Wiczling
fminsearch