get.events is a secondary function called by dde.model. It
creates a data.frame of events from the bolus dosing records found in the
dataset. get.events is typically not called directly by users.
get.events(bolus = NULL,
scale = NULL)Return a data.frame of events with the following elements:
A name of the state affected by the event
The time of the event
The value associated with the event
How the event affects the state ('add' by default)
See events for more details
b x 4 data.frame providing the instantaneous inputs
s x 1 vector of scaling factors
Sebastien Bihorel (sb.pmlab@gmail.com)
codeevents