get.secondary is a secondary function called during estimation runs by
fitmle.cov. It computes estimates of secondary parameters and related
statistics (covariance, coefficient of variations, and confidence intervals).
get.secondary is typically not called directly by users.
get.secondary(subproblem = NULL,
x = NULL)Return a list of with the following elements:
The vector of s secondary parameter estimates derived from initial structural model parameter estimates.
The vector of s secondary parameter estimates derived from final structural model parameter estimates.
The vector of s secondary parameter names.
The p x s matrix of partial derivatives for the secondary parameters.
A list containing the following levels:
A list containing as many levels as there are treatment levels
for the subject (or population) being evaluated, plus the trts
level listing all treatments for this subject (or population), and the
id level giving the identification number of the subject (or set to
1 if the analysis was run at the level of the population.
Each treatment-specific level is a list containing the following levels:
mij x 3 data.frame containing the times of observations of the dependent variables (extracted from the TIME variable), the indicators of the type of dependent variables (extracted from the CMT variable), and the actual dependent variable observations (extracted from the DV variable) for this particular treatment.
mij x c data.frame containing the times of observations of the dependent variables (extracted from the TIME variable) and all the covariates identified for this particular treatment.
bij x 4 data.frame providing the instantaneous inputs for a treatment and individual.
fij x (4+c) data.frame providing the zero-order inputs for a treatment and individual.
the particular treatment identifier.
A character string, indicating the scale of the analysis. Should be 'population' or 'subject'.
A data.frame of parameter data with the following columns: 'names', 'type', 'value', 'isfix', 'lb', and 'ub'.
Logical indicator of debugging mode.
Model function.
The vector of p parameter estimates.
Sebastien Bihorel (sb.pmlab@gmail.com)
fitmle.cov