pder is a secondary function called by get.cov.matrix. It
computes the matrix of partial derivatives for the model predictions and the
residual variability. pder is typically not called directly by users.
pder(subproblem = NULL,
x = NULL)Return a list containing the p x p matrices of partial
derivatives for model predictions (mpder) and residual variability
(wpder).
A list containing the following levels:
A list of R code extracted from the model file. Depending on content of the model file, the levels of this list could be: template, derived, lags, ode, dde, output, variance, and/or secondary.
A character string, indicating the scale of the analysis. Should be 'population' or 'subject'.
A data.frame of parameter data with the following columns: 'names', 'type', 'value', 'isfix', 'lb', and 'ub'.
Logical indicator of debugging mode.
Model function.
A list containing the following levels:
1 x m matrix of time of observations of the dependent variables.
m x 3 data.frame containing the times of observations of the dependent variables (extracted from the TIME variable), the indicators of the type of dependent variables (extracted from the CMT variable), and the actual dependent variable observations (extracted from the DV variable).
bij x 4 data.frame providing the instantaneous inputs for a treatment and individual.
fij x (4+c) data.frame providing the zero-order inputs for a treatment and individual.
mij x c data.frame containing the times of observations of the dependent variables (extracted from the TIME variable) and all the covariates identified for this particular treatment.
The vector of p final parameter estimates.
Sebastien Bihorel (sb.pmlab@gmail.com)
get.cov.matrix