scarabee.analysis is the de facto gateway for running any kind
of analysis with scaRabee. All other functions distributed with this
package are secondary functions called directly or indirectly by
scarabee.analysis.
Arguments for scarabee.analysis are best defined using the template
distributed with the package.
scarabee.analysis(files = NULL,
method = 'population',
runtype = NULL,
debugmode = FALSE,
estim.options = NULL,
npts = NULL,
alpha = NULL,
solver.options = list(method='lsoda'))Run an analysis until completion. See
vignette('scaRabee',package='scaRabee') for more details about the
expected outputs for an estimation, a simulation, or a gird search run.
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A character string, indicating the scale of the analysis. Should be 'population' or 'subject'.
A character string, indicating the type of analysis. Should be 'simulation', 'estimation', or 'gridsearch'.
A logical value, indicating the debug mode should be turn on
(TRUE) or off (default). Used only for estimation runs. If turn on,
the user could have access to error message returned when the model and
residual variability are evaluated in fitmle before the likelihood
is computed.
A list of estimation options containing two elements
maxiter (the maximum number of iterations) and maxeval (the
maximum number of function evaluations).
Only necessary if runtype is set to 'gridsearch'; npts
represents the number of points to be created by dimension of the grid
search.
Only necessary if runtype is set to 'gridsearch';
alpha is a real number, representing the factor applied to the
initial estimates of the model parameters to determine the lower and upper
bounds to the grid search space.
A list of differential equation solver options. Currently not modifiable by users.
Sebastien Bihorel (sb.pmlab@gmail.com)
fitmle