scarabee.check.reserved is a secondary function called at each
scaRabee run. It determined whether user-defined parameter names use
reserved names and if some user-defined parameters are related to the dosing
history. scarabee.check.reserved is typically not called directly by
users. scarabee.check.reserved is typically not called directly by
users.
scarabee.check.reserved(names = NULL, covnames = NULL)
A vector of parameter names, typically extracted from the file of parameter definition.
A vector of covariate names, typically extracted from the data file.
Sebastien Bihorel (sb.pmlab@gmail.com)
If one or more user-defined parameters are found to use reserved names, the run is stopped and the user is ask to update the name(s) of this(ese) parameter(s).