scarabee.directory is a secondary function called at each
scaRabee run. It creates a directory to store the results of the run and
a sub-directory to backup all files used for the run. This directory is
referred to as the 'run directory' in all scaRabee documentation and
help. scarabee.directory is typically not called directly by users.
scarabee.directory(curwd = getwd(),
files = NULL,
runtype = NULL,
analysis = NULL)When scarabee.directory is called, a new folder is created in the
working directory. The name of the new folder is a combination of the string
directly following the $ANALYSIS tag in the model file, an abbreviation of the
type of run ('est' for estimation, 'sim' for simulation, or 'grid' for grid
search) and an incremental integer, e.g. 'test.est.01'. This directory
contains the text and graph outputs of the run.
Additionally, a sub-directory called run.config.files is created into
the new folder and all the files defining the run, i.e. the dataset, the file
of initial model parameters, the model file and the master R script), are
stored.
The current working directory.
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A .csv file reporting the values of the objective function and estimates of model parameters at each iteration. (Not used for simulation runs).
A text file reporting for each individual in the dataset the final parameter estimates for structural model parameters, residual variability and secondary parameters as well as the related statistics (coefficients of variation, confidence intervals, covariance and correlation matrix). (Not used for simulation runs).
A .csv file reporting the predictions and calculated residuals for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the final parameter estimates for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the simulated model predictions for each individual in the dataset. (Not used for estimation runs).
A character string, indicating the type of analysis. Should be 'simulation', 'estimation', or 'gridsearch'.
A character string directly following the $ANALYSIS tag in the model file.
Sebastien Bihorel (sb.pmlab@gmail.com)
scarabee.analysis