scarabee.new creates a new scaRabee analysis folder.
scarabee.new(name = 'myanalysis',
path = NULL,
type = 'simulation',
method = 'population',
template = 'ode')
A string of characters defining the name of the master analysis
script; name is also appended to the $ANALYSIS tag in the model file.
Default is 'myanalysis'.
A path where the analysis files must be created. The path must not yet exist.
A string of characters, either 'simulation', 'estimation', or 'gridsearch'. Default is 'simulation'.
A string of characters, either 'population' or 'subject'. Default is 'population'.
A string of characters, either 'explicit', 'ode' or 'dde'. Default is 'ode'.
Sebastien Bihorel (sb.pmlab@gmail.com)
The content of new scaRabee analysis folder path/
is:
name.RThe template-based scaRabee analysis script.
A template-based txt file for the definition of the
structural model. Depending on template, this text file contains
various tags which delimit blocks of R code needed when models are defined
with closed form solution ('explicit'), ordinary differential equations
('ode') or delay differential equations ('dde').
(optional) An empty comma-separated file for dosing, observations, and covariate information; contains the following default headers: OMIT, TRT, ID, TIME, AMT, RATE, CMT, EVID, DV, DVID, and MDV.
(optional) An empty comma-separated file for initial guesses of model parameter estimates; contains the following default headers: Parameter, Type, Value, Fixed, Lower bound, Upper bound.
If the path argument is NULL, then it is coerced to name, thus
creating a new folder in the current working directory.
See vignette('scaRabee',package='scaRabee') to learn about how to
specify your model based on those template files.