scarabee.read.model is a secondary function called at each
scaRabee run. It reads and processes the data contained in the specified
model file. This function performs numerous checks to ensure that the model
file contains the expected information. scarabee.read.model is
typically not be called directly by users.
scarabee.read.model(files = NULL,
runtype = NULL)Return a list with various levels, depending on the content of the model file and the type of run:
The character string which follows the $ANALYSIS tag.
A character string, indicating which scaRabee function needs to be called to evaluate the model. This level is set to 'ode.model' if the $ODE tag is detected, to 'dde.model' if the $DDE tag is detected, and to 'explicit.model' otherwise.
A character string containing the R code provided within the $DERIVED block. (Only for models defined with $ODE or $DDE).
A character string containing the R code provided within the $IC block. (Only for models defined with $ODE or $DDE).
A character string containing the R code provided within the $SCALE block. (Only for models defined with $ODE or $DDE).
A character string containing the R code provided within the $ODE or $DDE block. (Only for models defined with $ODE or $DDE).
A character string containing the R code provided within the $LAGS block. (Only for models defined with $DDE).
A character string containing the R code provided within the $OUTPUT block.
A character string containing the R code provided within the $VARIANCE block.
A character string containing the R code provided within the $SECONDARY block.
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A .csv file reporting the values of the objective function and estimates of model parameters at each iteration. (Not used for simulation runs).
A text file reporting for each individual in the dataset the final parameter estimates for structural model parameters, residual variability and secondary parameters as well as the related statistics (coefficients of variation, confidence intervals, covariance and correlation matrix). (Not used for simulation runs).
A .csv file reporting the predictions and calculated residuals for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the final parameter estimates for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the simulated model predictions for each individual in the dataset. (Not used for estimation runs).
A single character string, indicating the type of run; either 'estimation', 'simulation', or 'gridsearch'.
Sebastien Bihorel (sb.pmlab@gmail.com)
scarabee.analysis