scarabee.read.parms is a secondary function called at each
scaRabee run. It reads and checks the information contained in the
specified parameter file.scarabee.read.parms is typically not called
directly by users.
scarabee.read.parms(files = NULL)If the content of the parameter file is valid, scarabee.read.parms
returns a data.frame with the same content. The names of the data.frame columns are: names, type, value, isfix, lb, and ub.
A list of input used for the analysis. The following elements are expected and none of them could be null:
A .csv file located in the working directory, which contains
the dosing information, the observations of the dependent variable(s)
to be modeled, and possibly covariate information. The expected format
of this file is described in details in vignette('scaRabee',
package='scaRabee').
A .csv file located in the working directory, which contains
the initial guess(es) for the model parameter(s) to be optimized or used
for model simulation. The expected format of this file is described in
details in vignette('scaRabee',package='scaRabee').
A text file located in the working directory, which defines
the model. Models specified with explicit, ordinary or delay
differential equations are expected to respect a certain syntax and
organization detailed in vignette('scaRabee',package='scaRabee').
A .csv file reporting the values of the objective function and estimates of model parameters at each iteration. (Not used for simulation runs).
A text file reporting for each individual in the dataset the final parameter estimates for structural model parameters, residual variability and secondary parameters as well as the related statistics (coefficients of variation, confidence intervals, covariance and correlation matrix). (Not used for simulation runs).
A .csv file reporting the predictions and calculated residuals for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the final parameter estimates for each individual in the dataset. (Not used for simulation runs).
A .csv file reporting the simulated model predictions for each individual in the dataset. (Not used for estimation runs).
Sebastien Bihorel (sb.pmlab@gmail.com)
scarabee.analysis