weighting is a secondary function called during estimation run to
evaluate the model(s) of residual variability specified by the code provided
in the $VARIANCE block. weighting is typically not called directly by
users.
weighting(parms = NULL,
derparms = NULL,
codevar=NULL,
y=NULL,
xdata=NULL,
check=FALSE)Return a matrix of numeric values of the same dimension as f.
A vector of primary parameters.
A list of derived parameters, specified in the $DERIVED block of code.
The content of the R code specified within the $VARIANCE block in the model file.
The matrix of structural model predictions.
A vector of times at which the system is being evaluated.
An indicator whether checks should be performed to validate function inputs
Sebastien Bihorel (sb.pmlab@gmail.com)