bound.parameters: Forces parameter estimates between defined boundaries.
Description
bound.parameters is a utility function called during estimation runs.
It forces the parameter estimates to remain within the boundaries defined in
the .csv file of initial estimates. bound.parameters is typically not
called directly by users.
Usage
bound.parameters(x = NULL,
lb = NULL,
ub = NULL)
Value
Returns a vector of p values. The ith element of the returned vector
is: